@@ -58,7 +58,7 @@ int getiflist(char **ifacelist, int showspeed)
 #endif
 
 	/* initialize list */
-	*ifacelist = malloc(sizeof(char));
+	*ifacelist = (char *)malloc(sizeof(char));
 	if (*ifacelist == NULL) {
 		panicexit(__FILE__, __LINE__);
 	}
@@ -72,7 +72,7 @@ int getiflist(char **ifacelist, int showspeed)
 			sscanf(procline, "%63s", temp);
 			if (strlen(temp)>0 && (isdigit(temp[(strlen(temp)-1)]) || temp[(strlen(temp)-1)]==':')) {
 				sscanf(temp, "%31[^':']s", interface);
-				*ifacelist = realloc(*ifacelist, ( ( strlen(*ifacelist) + strlen(interface) + 2 ) * sizeof(char)) );
+				*ifacelist = (char *)realloc(*ifacelist, ( ( strlen(*ifacelist) + strlen(interface) + 2 ) * sizeof(char)) );
 				if (*ifacelist == NULL) {
 					panicexit(__FILE__, __LINE__);
 				}
@@ -84,7 +84,7 @@ int getiflist(char **ifacelist, int showspeed)
 				speed = getifspeed(interface);
 				if (speed > 0) {
 					snprintf(temp, 64, "(%u Mbit) ", speed);
-					*ifacelist = realloc(*ifacelist, ( ( strlen(*ifacelist) + strlen(temp) + 1 ) * sizeof(char)) );
+					*ifacelist = (char *)realloc(*ifacelist, ( ( strlen(*ifacelist) + strlen(temp) + 1 ) * sizeof(char)) );
 					if (*ifacelist == NULL) {
 						panicexit(__FILE__, __LINE__);
 					}
@@ -105,7 +105,7 @@ int getiflist(char **ifacelist, int showspeed)
 				if (di->d_name[0] == '.' || strlen(di->d_name) > 31) {
 					continue;
 				}
-				*ifacelist = realloc(*ifacelist, ( ( strlen(*ifacelist) + strlen(di->d_name) + 2 ) * sizeof(char)) );
+				*ifacelist = (char *)realloc(*ifacelist, ( ( strlen(*ifacelist) + strlen(di->d_name) + 2 ) * sizeof(char)) );
 				if (*ifacelist == NULL) {
 					panicexit(__FILE__, __LINE__);
 				}
@@ -117,7 +117,7 @@ int getiflist(char **ifacelist, int showspeed)
 				speed = getifspeed(di->d_name);
 				if (speed > 0) {
 					snprintf(temp, 64, "(%u Mbit) ", speed);
-					*ifacelist = realloc(*ifacelist, ( ( strlen(*ifacelist) + strlen(temp) + 1 ) * sizeof(char)) );
+					*ifacelist = (char *)realloc(*ifacelist, ( ( strlen(*ifacelist) + strlen(temp) + 1 ) * sizeof(char)) );
 					if (*ifacelist == NULL) {
 						panicexit(__FILE__, __LINE__);
 					}
@@ -326,7 +326,7 @@ void parseifinfo(int newdb)
 
 		/* btime in /proc/stat seems to vary 1 second so we use btime-BVAR just to be safe */
 		/* the variation is also slightly different between various kernels... */
-		if (data.btime < (btime-cfg.bvar)) {
+		if (data.btime < (btime-(unsigned)cfg.bvar)) {
 			data.currx=0;
 			data.curtx=0;
 			if (debug)
@@ -355,7 +355,7 @@ void parseifinfo(int newdb)
 
 			/* calculate maximum possible transfer since last update based on set maximum rate */
 			/* and add 10% in order to be on the safe side */
-			maxtransfer = ceil((maxbw/(float)8)*interval*(float)1.1);
+			maxtransfer = (uint64_t)(ceilf((maxbw/8.0f)*interval*1.1f));
 
 			if (debug)
 				printf("interval: %"PRIu64"  maxbw: %"PRIu32"  maxrate: %"PRIu64"  rxc: %"PRIu64"  txc: %"PRIu64"\n", (uint64_t)interval, maxbw, maxtransfer, rxchange, txchange);
