@@ -128,7 +128,7 @@ void colorinit(IMAGECONTENT *ic)
 	colorinitcheck("ctxd", ic->ctxd, cfg.ctxd, rgb);
 }
 
-void colorinitcheck(char *color, int value, char *cfgtext, int *rgb)
+void colorinitcheck(const char *color, int value, const char *cfgtext, const int *rgb)
 {
 	if (value==-1) {
 		printf("Error: ImageColorAllocate failed.\n");
@@ -162,7 +162,7 @@ void layoutinit(IMAGECONTENT *ic, char *title, int width, int height)
 	if (!ic->showheader || ic->altdate) {
 		gdImageString(ic->im, gdFontGetTiny(), 5+ic->showedge, height-12-ic->showedge, (unsigned char*)datestring, ic->cvnstat);
 	} else {
-		gdImageString(ic->im, gdFontGetTiny(), width-(strlen(datestring)*gdFontGetTiny()->w+12), 9+ic->showedge, (unsigned char*)datestring, ic->cheaderdate);
+		gdImageString(ic->im, gdFontGetTiny(), width-(((int)strlen(datestring))*gdFontGetTiny()->w+12), 9+ic->showedge, (unsigned char*)datestring, ic->cheaderdate);
 	}
 
 	/* generator */
