@@ -51,17 +51,31 @@ START_TEST(dmonth_return_within_range)
 }
 END_TEST
 
+#if defined(_SVID_SOURCE) || defined(_XOPEN_SOURCE) || defined(__linux__)
 START_TEST(mosecs_return_values)
 {
 	initdb();
 	defaultcfg();
 	ck_assert_int_eq(cfg.monthrotate, 1);
-	ck_assert_int_eq(mosecs(), 0);
+	ck_assert_int_eq(mosecs(), 1);
 	data.month[0].month = 172800;
 	data.lastupdated = 173000;
 	ck_assert_int_eq(mosecs(), 173000);
 }
 END_TEST
+#else
+START_TEST(mosecs_return_values_without_timezone)
+{
+	initdb();
+	defaultcfg();
+	ck_assert_int_eq(cfg.monthrotate, 1);
+	ck_assert_int_eq(mosecs(), 1);
+	data.month[0].month = 172800;
+	data.lastupdated = 173000;
+	ck_assert_int_gt(mosecs(), 1);
+}
+END_TEST
+#endif
 
 START_TEST(mosecs_does_not_change_tz)
 {
@@ -81,6 +95,7 @@ START_TEST(mosecs_does_not_change_tz)
 	data.lastupdated = 2;
 	ck_assert_int_eq(cfg.monthrotate, 1);
 	ck_assert_int_ne(mosecs(), 0);
+	ck_assert_int_ne(mosecs(), 1);
 	ck_assert_int_eq(timezone_before_call, timezone);
 }
 END_TEST
@@ -100,6 +115,7 @@ START_TEST(mosecs_does_not_change_struct_tm_pointer_content)
 	ck_assert_int_eq(cfg.monthrotate, 1);
 	ck_assert_int_eq(current, timelocal(stm));
 	ck_assert_int_ne(mosecs(), 0);
+	ck_assert_int_ne(mosecs(), 1);
 	ck_assert_int_eq(current, timelocal(stm));
 }
 END_TEST
@@ -386,7 +402,11 @@ void add_common_tests(Suite *s)
 	tcase_add_test(tc_common, printe_options);
 	tcase_add_test(tc_common, logprint_options);
 	tcase_add_loop_test(tc_common, dmonth_return_within_range, 0, 12);
+#if defined(_SVID_SOURCE) || defined(_XOPEN_SOURCE) || defined(__linux__)
 	tcase_add_test(tc_common, mosecs_return_values);
+#else
+	tcase_add_test(tc_common, mosecs_return_values_without_timezone);
+#endif
 	tcase_add_test(tc_common, mosecs_does_not_change_tz);
 	tcase_add_test(tc_common, mosecs_does_not_change_struct_tm_pointer_content);
 	tcase_add_test(tc_common, countercalc_no_change);
